<?php

/*
 * Copyright 2014 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
namespace WPMailSMTP\Vendor\Google\Service\Gmail;

class HistoryLabelRemoved extends \WPMailSMTP\Vendor\Google\Collection
{
    protected $collection_key = 'labelIds';
    /**
     * @var string[]
     */
    public $labelIds;
    protected $messageType = \WPMailSMTP\Vendor\Google\Service\Gmail\Message::class;
    protected $messageDataType = '';
    /**
     * @param string[]
     */
    public function setLabelIds($labelIds)
    {
        $this->labelIds = $labelIds;
    }
    /**
     * @return string[]
     */
    public function getLabelIds()
    {
        return $this->labelIds;
    }
    /**
     * @param Message
     */
    public function setMessage(\WPMailSMTP\Vendor\Google\Service\Gmail\Message $message)
    {
        $this->message = $message;
    }
    /**
     * @return Message
     */
    public function getMessage()
    {
        return $this->message;
    }
}
// Adding a class alias for backwards compatibility with the previous class name.
\class_alias(\WPMailSMTP\Vendor\Google\Service\Gmail\HistoryLabelRemoved::class, 'WPMailSMTP\\Vendor\\Google_Service_Gmail_HistoryLabelRemoved');
